@@ -1,4 +1,4 @@
-#  Copyright 2008-2013 Nokia Siemens Networks Oyj
+#  Copyright 2008-2014 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -12,6 +12,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from six import string_types
+
 import os
 
 from robot import utils
@@ -28,7 +30,8 @@ class _BaseSettings(object):
                  'Doc'              : ('doc', None),
                  'Metadata'         : ('metadata', []),
                  'TestNames'        : ('test', []),
-                 'RunFailed'        : ('runfailed', 'NONE'),
+                 'ReRunFailed'      : ('rerunfailed', 'NONE'),
+                 'DeprecatedRunFailed': ('runfailed', 'NONE'),
                  'SuiteNames'       : ('suite', []),
                  'SetTag'           : ('settag', []),
                  'Include'          : ('include', []),
@@ -70,10 +73,10 @@ class _BaseSettings(object):
     def _process_cli_opts(self, opts):
         for name, (cli_name, default) in self._cli_opts.items():
             value = opts[cli_name] if cli_name in opts else default
-            if default == [] and isinstance(value, basestring):
+            if default == [] and isinstance(value, string_types):
                 value = [value]
             self[name] = self._process_value(name, value)
-        self['TestNames'] += self['RunFailed']
+        self['TestNames'] += self['ReRunFailed'] or self['DeprecatedRunFailed']
         if self['DeprecatedXUnit']:
             self['XUnit'] = self['DeprecatedXUnit']
 
@@ -83,7 +86,7 @@ class _BaseSettings(object):
         self._opts[name] = value
 
     def _process_value(self, name, value):
-        if name == 'RunFailed':
+        if name in ['ReRunFailed', 'DeprecatedRunFailed']:
             return gather_failed_tests(value)
         if name == 'LogLevel':
             return self._process_log_level(value)
@@ -98,7 +101,7 @@ class _BaseSettings(object):
                 value = [self._escape_as_data(v) for v in value]
             return [self._process_metadata_or_tagdoc(v) for v in value]
         if name in ['Include', 'Exclude']:
-            return [v.replace('AND', '&').replace('_', ' ') for v in value]
+            return [self._format_tag_patterns(v) for v in value]
         if name in self._output_opts and (not value or value.upper() == 'NONE'):
             return None
         if name == 'DeprecatedXUnit':
@@ -219,7 +222,7 @@ class _BaseSettings(object):
         try:
             if not os.path.exists(path):
                 os.makedirs(path)
-        except EnvironmentError, err:
+        except EnvironmentError as err:
             raise DataError("Creating %s file directory '%s' failed: %s"
                             % (type_.lower(), path, err.strerror))
 
@@ -237,13 +240,21 @@ class _BaseSettings(object):
             return colors[0], colors[0], colors[1]
         return tuple(colors)
 
-    def _process_tag_stat_combine(self, value):
-        for replwhat, replwith in [('&', 'AND'), ('AND', ' AND '), ('NOT', ' NOT ')]:
-            value = value.replace(replwhat, replwith)
-        if ':' not in value:
-            return value, ''
-        pattern, title = value.rsplit(':', 1)
-        return pattern, title.replace('_', ' ')
+    def _process_tag_stat_combine(self, pattern):
+        if ':' in pattern:
+            pattern, title = pattern.rsplit(':', 1)
+        else:
+            title = ''
+        return self._format_tag_patterns(pattern), title.replace('_', ' ')
+
+    def _format_tag_patterns(self, pattern):
+        for search, replace in [('&', 'AND'), ('AND', ' AND '), ('OR', ' OR '),
+                                ('NOT', ' NOT '), ('_', ' ')]:
+            if search in pattern:
+                pattern = pattern.replace(search, replace)
+        while '  ' in pattern:
+            pattern = pattern.replace('  ', ' ')
+        return pattern
 
     def _process_tag_stat_link(self, value):
         tokens = value.split(':')
@@ -283,14 +294,14 @@ class _BaseSettings(object):
         for value in values:
             try:
                 KeywordRemover(value)
-            except DataError, err:
+            except DataError as err:
                 raise DataError("Invalid value for option '--removekeywords'. %s" % err)
 
     def _validate_flatten_keywords(self, values):
         for value in values:
             try:
                 FlattenKeywordMatcher(value)
-            except DataError, err:
+            except DataError as err:
                 raise DataError("Invalid value for option '--flattenkeywords'. %s" % err)
 
     def __contains__(self, setting):
@@ -434,6 +445,16 @@ class RobotSettings(_BaseSettings):
         return (self['SkipTeardownOnExit'] or
                 any(mode == 'skipteardownonexit' for mode in self['RunMode']))
 
+    @property
+    def console_logger_config(self):
+        return {
+            'width':   self['MonitorWidth'],
+            'colors':  self['MonitorColors'],
+            'markers': self['MonitorMarkers'],
+            'stdout':  self['StdOut'],
+            'stderr':  self['StdErr']
+        }
+
 
 class RebotSettings(_BaseSettings):
     _extra_cli_opts = {'Output'            : ('output', None),
@@ -441,7 +462,7 @@ class RebotSettings(_BaseSettings):
                        'ProcessEmptySuite' : ('processemptysuite', False),
                        'StartTime'         : ('starttime', None),
                        'EndTime'           : ('endtime', None),
-                       'RunFailed'         : ('runfailed', 'NONE')}
+                       'ReRunMerge'        : ('rerunmerge', False)}
 
     def _output_disabled(self):
         return False
@@ -495,3 +516,15 @@ class RebotSettings(_BaseSettings):
     def _resolve_background_colors(self):
         colors = self['ReportBackground']
         return {'pass': colors[0], 'nonCriticalFail': colors[1], 'fail': colors[2]}
+
+    @property
+    def rerun_merge(self):
+        return self['ReRunMerge']
+
+    @property
+    def console_logger_config(self):
+        return {
+            'colors':  self['MonitorColors'],
+            'stdout':  self['StdOut'],
+            'stderr':  self['StdErr']
+        }
