@@ -1,4 +1,4 @@
-#  Copyright 2008-2013 Nokia Siemens Networks Oyj
+#  Copyright 2008-2014 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -12,7 +12,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import with_statement
+from six import PY3, text_type as unicode
+
 import os
 import sys
 import tempfile
@@ -715,13 +716,18 @@ class OperatingSystem:
     # Moving and copying files and directories
 
     def copy_file(self, source, destination):
-        """Copies the source file into a new destination.
+        """Copies the source file into the destination.
+
+        Source must be an existing file. Starting from Robot Framework 2.8.4,
+        it can be given as a glob pattern (see `Pattern matching`) that matches
+        exactly one file. How the destination is interpreted is explained below.
 
         1) If the destination is an existing file, the source file is copied
         over it.
 
         2) If the destination is an existing directory, the source file is
-        copied into it. A possible file with the same name is overwritten.
+        copied into it. A possible file with the same name as the source is
+        overwritten.
 
         3) If the destination does not exist and it ends with a path
         separator ('/' or '\\'), it is considered a directory. That
@@ -731,23 +737,88 @@ class OperatingSystem:
         4) If the destination does not exist and it does not end with a path
         separator, it is considered a file. If the path to the file does not
         exist, it is created.
+
+        See also `Copy Files`, `Move File`, and `Move Files`.
         """
         source, destination = self._copy_file(source, destination)
         self._link("Copied file from '%s' to '%s'", source, destination)
 
     def move_file(self, source, destination):
-        """Moves the source file into a new destination.
-
-        If the source and destination are in the same filesystem, rename operation is used.
-        Otherwise file is copied to the destination filesystem and then removed from the
-        original filesystem.
+        """Moves the source file into the destination.
 
         Arguments have exactly same semantics as with `Copy File` keyword.
+
+        If the source and destination are on the same filesystem, rename
+        operation is used. Otherwise file is copied to the destination
+        filesystem and then removed from the original filesystem.
+
+        See also `Move Files`, `Copy File`, and `Copy Files`.
         """
         source, destination, _ = self._prepare_for_move_or_copy(source, destination)
         shutil.move(source, destination)
         self._link("Moved file from '%s' to '%s'", source, destination)
 
+    def copy_files(self, *sources_and_destination):
+        """Copies specified files to the target directory.
+
+        Source files can be given as exact paths and as glob patterns (see
+        `Pattern matching`). At least one source must be given, but it is
+        not an error if it is a pattern that does not match anything.
+
+        Last argument must be the destination directory. If the destination
+        does not exist, it will be created.
+
+        Examples:
+        | Copy Files | ${dir}/file1.txt  | ${dir}/file2.txt | ${dir2} |
+        | Copy Files | ${dir}/file-*.txt | ${dir2}          |         |
+
+        See also `Copy File`, `Move File`, and `Move Files`.
+
+        New in Robot Framework 2.8.4.
+        """
+        source_files, dest_dir = self._parse_sources_and_destination(sources_and_destination)
+        for source in source_files:
+            self.copy_file(source, dest_dir)
+
+    def move_files(self, *sources_and_destination):
+        """Moves specified files to the target directory.
+
+        Arguments have exactly same semantics as with `Copy Files` keyword.
+
+        See also `Move File`, `Copy File`, and `Copy Files`.
+
+        New in Robot Framework 2.8.4.
+        """
+        source_files, dest_dir = self._parse_sources_and_destination(sources_and_destination)
+        for source in source_files:
+            self.move_file(source, dest_dir)
+
+    def _parse_sources_and_destination(self, items):
+        if len(items) < 2:
+            raise RuntimeError("Must contain destination and at least one source")
+        sources, destination = items[:-1], items[-1]
+        self._ensure_destination_directory(destination)
+        return self._glob_files(sources), destination
+
+    def _normalize_dest(self, dest):
+        dest = dest.replace('/', os.sep)
+        dest_is_dir = dest.endswith(os.sep) or os.path.isdir(dest)
+        dest = self._absnorm(dest)
+        return dest, dest_is_dir
+
+    def _ensure_destination_directory(self, destination):
+        destination, _ = self._normalize_dest(destination)
+        if not os.path.exists(destination):
+            os.makedirs(destination)
+        elif not os.path.isdir(destination):
+            raise RuntimeError("Destination '%s' exists and is not a directory" % destination)
+
+    def _glob_files(self, patterns):
+        files = []
+        for pattern in patterns:
+            files.extend(glob.glob(self._absnorm(pattern)))
+        return files
+
     def _prepare_for_move_or_copy(self, source, dest):
         source, dest, dest_is_dir = self._normalize_source_and_dest(source, dest)
         self._verify_that_source_is_a_file(source)
@@ -766,10 +837,11 @@ class OperatingSystem:
         return self._atomic_copy(source, dest, parent)
 
     def _normalize_source_and_dest(self, source, dest):
-        source = self._absnorm(source)
-        dest = dest.replace('/', os.sep)
-        dest_is_dir = dest.endswith(os.sep) or os.path.isdir(dest)
-        dest = self._absnorm(dest)
+        sources = self._glob_files([source])
+        if len(sources) > 1:
+            raise RuntimeError("Multiple matches with source pattern '%s'" % source)
+        source = sources[0] if sources else source
+        dest, dest_is_dir = self._normalize_dest(dest)
         return source, dest, dest_is_dir
 
     def _verify_that_source_is_a_file(self, source):
@@ -873,6 +945,40 @@ class OperatingSystem:
         set_env_var(name, value)
         self._info("Environment variable '%s' set to value '%s'" % (name, value))
 
+    def append_to_environment_variable(self, name, *values, **config):
+        """Appends given `values` to environment variable `name`.
+
+        If the environment variable already exists, values are added after it,
+        and otherwise a new environment variable is created.
+
+        Values are, by default, joined together using the operating system
+        path separator (';' on Windows, ':' elsewhere). This can be changed
+        by giving a separator after the values like `separator=value`. No
+        other configuration parameters are accepted.
+
+        Examples (assuming `NAME` and `NAME2` do not exist initially):
+        | Append To Environment Variable | NAME     | first  |       |
+        | Should Be Equal                | %{NAME}  | first  |       |
+        | Append To Environment Variable | NAME     | second | third |
+        | Should Be Equal                | %{NAME}  | first${:}second${:}third |
+        | Append To Environment Variable | NAME2    | first  | separator=-     |
+        | Should Be Equal                | %{NAME2} | first  |                 |
+        | Append To Environment Variable | NAME2    | second | separator=-     |
+        | Should Be Equal                | %{NAME2} | first-second             |
+
+        New in Robot Framework 2.8.4.
+        """
+        sentinel = object()
+        initial = self.get_environment_variable(name, sentinel)
+        if initial is not sentinel:
+            values = (initial,) + values
+        separator = config.pop('separator', os.pathsep)
+        if config:
+            config = ['='.join(i) for i in sorted(config.items())]
+            raise RuntimeError('Configuration %s not accepted.'
+                               % seq2str(config, lastsep=' or '))
+        self.set_environment_variable(name, separator.join(values))
+
     def remove_environment_variable(self, *names):
         """Deletes the specified environment variable.
 
@@ -1147,7 +1253,7 @@ class OperatingSystem:
             if not os.path.isfile(path):
                 raise ValueError('Modified time can only be set to regular files')
             mtime = parse_time(mtime)
-        except ValueError, err:
+        except ValueError as err:
             raise RuntimeError("Setting modified time of '%s' failed: %s"
                                % (path, unicode(err)))
         os.utime(path, (mtime, mtime))
@@ -1295,7 +1401,7 @@ class OperatingSystem:
         if logger:
             logger.write(msg, level)
         else:
-            print '*%s* %s' % (level, msg)
+            print('*%s* %s' % (level, msg))
 
 
 class _Process:
@@ -1333,7 +1439,7 @@ class _Process:
                 command = command[:-1] + ' 2>&1 &'
             else:
                 command += ' 2>&1'
-        if sys.version_info[0] == 3:
+        if PY3:
             return command
         return self._encode_to_file_system(command)
 
@@ -1345,7 +1451,7 @@ class _Process:
         stdout = stdout.replace('\r\n', '\n') # http://bugs.jython.org/issue1566
         if stdout.endswith('\n'):
             stdout = stdout[:-1]
-        return decode_output(stdout)
+        return decode_output(stdout, force=True)
 
 
 class _Process2(_Process):
